# Model Evaluation Tools

Package to evaluate the performance of a classification model. 

The package allows to :
  - Generate a performance report with commonly used metrics (accuracy, precision, recall, f1, roc_auc)
  - Calculate the optimal classification threshold based on a selected performance metric
  - Visualize the change on the performance based on different prediction thresholds
  - Generate a lift table to evaluate the performance of the model
  - Generate a lift chart to evaluate the performance of the model